@@ -69,8 +69,13 @@ def compare_ipynb_notebooks(notebook_filenames, debug):
                                  cells[1]["outputs"],
                                  debug)
 
-            # Empty output is not necessarily bad, print it
-            print_empty_output(cells)
+            # Check for different number of output fields
+            output_length_errors = check_output_field_number(cells, debug)
+
+            comparison_errors.extend(output_length_errors)
+
+            # Print all output, even if empty
+            print_all_output(cells)
 
             # Loop over outputs - can have multiple for each source cell
             for outputs in zip(cells[0]["outputs"], cells[1]["outputs"]):
@@ -117,18 +122,31 @@ def compare_ipynb_notebooks(notebook_filenames, debug):
     return comparison_result, error_message, error_content
 
 
-def print_empty_output(cells):
-    len_0_output = len(cells[0]["outputs"])
-    len_1_output = len(cells[1]["outputs"])
+def check_output_field_number(cells, debug):
+    output_length_errors = []
+    len0 = len(cells[0]["outputs"])
+    len1 = len(cells[1]["outputs"])
+    debug and print("len(cells_0_outputs): ", len0)
+    debug and print("len(cells_1_outputs): ", len1)
 
-    (len_0_output == 0 or len_1_output == 0) and \
-        print(BLUE, "-".center(80, "-"), NC)
-    len_0_output == 0 and print(CYAN, "cells[0][outputs]: ", NC) \
-        and print_cropped_output(cells[0]["outputs"])
-    len_1_output == 0 and print(CYAN, "cells[1][outputs]: ", NC) \
-        and print_cropped_output(cells[1]["outputs"])
-    (len_0_output == 0 or len_1_output == 0) and \
-        print(BLUE, "-".center(80, "-"), NC)
+    if len0 != len1:
+        print(RED)
+        message = "the number of output fields in not the same"
+        print(message, NC)
+        output_length_errors.append(cells[0]["outputs"])
+        output_length_errors.append(cells[1]["outputs"])
+        logging.info(message)
+
+    return output_length_errors
+
+
+def print_all_output(cells):
+    print(BLUE, "-".center(80, "-"), NC)
+    print(CYAN, "cells[0][outputs]: ", NC)
+    print_cropped_output(cells[0]["outputs"])
+    print(CYAN, "cells[1][outputs]: ", NC)
+    print_cropped_output(cells[1]["outputs"])
+    print(BLUE, "-".center(80, "-"), NC)
 
 
 def remove_warning_ouput(cells_0_outputs, cells_1_outputs, debug):
@@ -146,11 +164,13 @@ def remove_warning_ouput(cells_0_outputs, cells_1_outputs, debug):
     warnings_to_ignore["text"] = [
         "DeprecationWarning",
         "History will not be written to the database",
+        "Notebook initialized with",
     ]
 
     # Look for the warning output and remove it from further consideration
     for outputs in [cells_0_outputs, cells_1_outputs]:
         for index, output in enumerate(outputs):
+            list_of_elements_to_remove = []
             for key in warnings_to_ignore:
                 if key in output:
                     for value in warnings_to_ignore[key]:
@@ -158,7 +178,16 @@ def remove_warning_ouput(cells_0_outputs, cells_1_outputs, debug):
                             debug and print(CYAN, "ignore warning", index,
                                             value, YELLOW, "\n   ",
                                             output[key], NC)
-                            outputs.pop(index)
+                            list_of_elements_to_remove.append(index)
+
+            # Remove repeats of indicies
+            list_of_elements_to_remove = \
+                list(dict.fromkeys(list_of_elements_to_remove))
+
+            # Remove specified elements from array
+            for index in list_of_elements_to_remove:
+                debug and print(CYAN, "removing index: ", index, NC)
+                outputs.pop(index)
 
     len0 = len(cells_0_outputs)
     len1 = len(cells_1_outputs)
